==> rong-ui-react-0.0.5.tgz: package/es/select3/select3.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); Object.defineProperty(subClass, "prototype", { writable: false }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

import React from 'react';
import PropTypes from 'prop-types';
import AsyncValidator from 'async-validator';
import { setDefaultProps, classNames } from '../_util/assist';
import { Consumer } from '../form/formContext';
var prefixCls = 'r-select3';

var Select3 = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(Select3, _React$PureComponent);

  var _super = _createSuper(Select3);

  function Select3(props) {
    var _this;

    _classCallCheck(this, Select3);

    _this = _super.call(this, props);
    _this.state = {
      value: props.value,
      prePropsValue: props.value,
      validateState: '',
      validateMessage: ''
    }; // 不需要驱动视图更新的数据放这里

    _this._state = {
      initialValue: '',
      isMounted: false
    };
    _this.selectWrapRef = /*#__PURE__*/React.createRef();
    return _this;
  }

  _createClass(Select3, [{
    key: "render",
    value: function render() {
      var _this2 = this;

      return /*#__PURE__*/React.createElement(Consumer, null, function (context) {
        _this2.form = context;
        console.log('Select3 mounted or updated');
        var _this2$props = _this2.props,
            title = _this2$props.title,
            prepend = _this2$props.prepend,
            append = _this2$props.append,
            data = _this2$props.data;
        var validateMessage = _this2.state.validateMessage;
        return /*#__PURE__*/React.createElement("div", {
          className: _this2.wrapCls,
          ref: _this2.selectWrapRef
        }, /*#__PURE__*/React.createElement("div", {
          className: _this2.innerCls
        }, /*#__PURE__*/React.createElement("label", {
          className: _this2.labelCls,
          style: _this2.labelStyle
        }, title), prepend && /*#__PURE__*/React.createElement("div", {
          className: _this2.prependCls
        }, prepend), /*#__PURE__*/React.createElement("div", {
          className: _this2.contentCls
        }, data.map(function (item) {
          return /*#__PURE__*/React.createElement("div", {
            key: item.value,
            className: classNames([_this2.selectOptionCls, {
              active: _this2.state.value === item.value
            }]),
            onClick: function onClick(e) {
              return _this2.onSelect(e, item);
            }
          }, item.text);
        })), append && /*#__PURE__*/React.createElement("div", {
          className: _this2.appendCls
        }, append)), _this2.selectedOption.children && _this2.selectedOption.children.length && /*#__PURE__*/React.createElement("div", {
          className: _this2.wrapChildrenCls
        }, _this2.selectedOption.children.map(function (item, index) {
          return /*#__PURE__*/React.createElement(item.component, _extends({}, item, {
            "data-index": index,
            item: item,
            key: item.name
          }));
        })), _this2.showErrorMsg && /*#__PURE__*/React.createElement("div", {
          className: _this2.errorCls
        }, validateMessage));
      });
    }
  }, {
    key: "componentDidMount",
    value: function componentDidMount() {
      this.form && this.form.addField(this);
      this._state.initialValue = this.state.value;
      this._state.isMounted = true;
      this.$el = this.selectWrapRef.current;
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      this.form && this.form.removeField(this);
      this._state.isMounted = false;
    }
  }, {
    key: "wrapCls",
    get: function get() {
      var _ref;

      var value = this.state.value;
      var _this$props = this.props,
          labelPosition = _this$props.labelPosition,
          textPosition = _this$props.textPosition,
          mode = _this$props.mode,
          className = _this$props.className,
          readonly = _this$props.readonly;

      var _labelPosition = labelPosition || this.form && this.form.labelPosition || 'left';

      var _textPosition = textPosition || this.form && this.form.textPosition || 'left';

      var _mode = mode || this.form && this.form.mode || 'default';

      return classNames([this.form && 'form-item', prefixCls, "".concat(prefixCls, "-label-").concat(_labelPosition), "".concat(prefixCls, "-text-").concat(_textPosition), "".concat(prefixCls, "-mode-").concat(_mode), className, (_ref = {}, _defineProperty(_ref, "".concat(prefixCls, "-empty"), value === ''), _defineProperty(_ref, "".concat(prefixCls, "-error"), this.showErrorMsg), _defineProperty(_ref, "".concat(prefixCls, "-required"), this.isRequired), _defineProperty(_ref, "".concat(prefixCls, "-readonly"), !!readonly), _ref)]);
    }
  }, {
    key: "innerCls",
    get: function get() {
      return "".concat(prefixCls, "-inner");
    }
  }, {
    key: "wrapChildrenCls",
    get: function get() {
      return "".concat(prefixCls, "-children");
    }
  }, {
    key: "labelCls",
    get: function get() {
      return "".concat(prefixCls, "-label");
    }
  }, {
    key: "labelStyle",
    get: function get() {
      var style = {};

      if (this.labelWidth || this.labelWidth === 0) {
        style.width = this.labelWidth;
      } else if (this.form && (this.form.labelWidth || this.form.labelWidth === 0)) {
        style.width = this.form.labelWidth;
      }

      return style;
    }
  }, {
    key: "prependCls",
    get: function get() {
      return "".concat(prefixCls, "-prepend");
    }
  }, {
    key: "appendCls",
    get: function get() {
      return "".concat(prefixCls, "-append");
    }
  }, {
    key: "selectedOption",
    get: function get() {
      var data = this.props.data;
      var value = this.state.value;
      var selectedOption = {};

      for (var i = 0; i < data.length; i++) {
        if (data[i].value === value) {
          selectedOption = data[i];
          break;
        }
      }

      return selectedOption;
    }
  }, {
    key: "contentCls",
    get: function get() {
      return "".concat(prefixCls, "-content");
    }
  }, {
    key: "selectCls",
    get: function get() {
      return "".concat(prefixCls, "-select");
    }
  }, {
    key: "selectOptionCls",
    get: function get() {
      return "".concat(prefixCls, "-select-option");
    }
  }, {
    key: "errorCls",
    get: function get() {
      return "".concat(prefixCls, "-error-tip");
    }
  }, {
    key: "fieldRules",
    get: function get() {
      var _this$props2 = this.props,
          title = _this$props2.title,
          rules = _this$props2.rules;
      var defaultRules = [{
        required: true,
        message: "".concat(title, "\u4E0D\u80FD\u4E3A\u7A7A")
      }];
      return [].concat(rules ? rules : defaultRules);
    }
  }, {
    key: "isRequired",
    get: function get() {
      return this.props.required && this.fieldRules.length > 0;
    }
  }, {
    key: "showErrorMsg",
    get: function get() {
      return this.state.validateState === 'error' && (this.form ? this.form.showMessage && this.props.showMessage : this.props.showMessage);
    }
  }, {
    key: "onSelect",
    value: function onSelect(e, item) {
      var _this$props3 = this.props,
          readonly = _this$props3.readonly,
          disabled = _this$props3.disabled;
      if (readonly || disabled) return;
      this.setValue(item.value, function () {}, {
        event: e,
        from: 'select'
      });
    }
  }, {
    key: "getFilterRules",
    value: function getFilterRules(trigger) {
      return this.fieldRules.filter(function (rule) {
        return !rule.trigger || rule.trigger.indexOf(trigger) !== -1;
      });
    }
  }, {
    key: "validate",
    value: function validate(trigger) {
      var _this3 = this;

      var callback = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : function () {};
      var value = this.state.value;
      var initialValue = this._state.initialValue;
      var _this$props4 = this.props,
          name = _this$props4.name,
          title = _this$props4.title;
      var rules = this.getFilterRules(trigger);
      var isInitialValue = this.isRequired && value !== '' && initialValue === value;

      if (!this.isRequired || isInitialValue) {
        callback();
        return true;
      }

      var prop = name || title || 'prop';
      var descriptor = {};
      descriptor[prop] = rules;
      var validator = new AsyncValidator(descriptor);
      var model = {};
      model[prop] = value;
      validator.validate(model, {
        first: true,
        suppressWarning: true,
        component: this
      }).then(function () {
        _this3.setState({
          validateState: 'success',
          validateMessage: ''
        });

        callback('');
      }).catch(function (_ref2) {
        var errors = _ref2.errors,
            fields = _ref2.fields;
        var errMsg = errors[0].message || '';

        _this3.setState({
          validateState: 'error',
          validateMessage: errMsg
        });

        callback(errMsg);
      });
    }
  }, {
    key: "resetField",
    value: function resetField() {
      this.setState({
        validateState: '',
        validateMessage: ''
      });
      this.setValue(this._state.initialValue, null, {
        from: 'reset'
      });
    }
    /* 获取表单数据 */

  }, {
    key: "getValue",
    value: function getValue() {
      return {
        name: this.props.name,
        value: this.state.value,
        title: this.props.title
      };
    }
  }, {
    key: "setValue",
    value: function setValue(value, callback) {
      var _this4 = this;

      var options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
      var opts = Object.assign({
        event: null,
        component: this,
        value: value
      }, options);
      var from = options.from;
      this._state.isMounted && this.setState({
        value: value
      }, function () {
        _this4.props.onChange(opts);

        _this4.form && _this4.form.onChange(opts);
        callback && callback.call(_this4);

        if (from === 'select') {
          _this4.validate('blur');
        }
      });
    }
  }], [{
    key: "getDerivedStateFromProps",
    value: function getDerivedStateFromProps(nextProps, prevState) {
      if (nextProps.value !== prevState.prePropsValue) {
        return {
          value: nextProps.value,
          prePropsValue: nextProps.value
        };
      }

      return null;
    }
  }]);

  return Select3;
}(React.PureComponent);

setDefaultProps(Select3, {
  title: {
    type: PropTypes.string
  },
  value: {
    type: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
    default: ''
  },
  disabled: {
    type: PropTypes.oneOf(['disabled', 1, 0, true, false])
  },
  readonly: {
    type: PropTypes.oneOf(['readonly', 1, 0, true, false])
  },
  labelPosition: {
    type: PropTypes.oneOf(['left', 'right', 'top'])
  },
  labelWidth: {
    type: PropTypes.string
  },
  textPosition: {
    type: PropTypes.oneOf(['left', 'center', 'right'])
  },
  data: {
    type: PropTypes.array,
    default: []
  },
  // 是否显示校验错误信息
  showMessage: {
    type: PropTypes.bool,
    default: true
  },
  // 校验规则
  rules: {
    type: PropTypes.array
  },
  required: {
    type: PropTypes.bool,
    default: true
  },
  onChange: {
    type: PropTypes.func,
    default: function _default() {}
  },
  mode: {
    type: PropTypes.string
  }
});
export default Select3;

==> rong-ui-react-0.0.8.tgz: package/es/select3/select3.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); Object.defineProperty(subClass, "prototype", { writable: false }); if (superClass) _setPrototypeOf(subClass, superClass); }
function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }
function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }
function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }
function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }
function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }
function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }
import React from 'react';
import PropTypes from 'prop-types';
import AsyncValidator from 'async-validator';
import { setDefaultProps, classNames } from '../_util/assist';
import { Consumer } from '../form/formContext';
var prefixCls = 'r-select3';
var Select3 = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(Select3, _React$PureComponent);
  var _super = _createSuper(Select3);
  function Select3(props) {
    var _this;
    _classCallCheck(this, Select3);
    _this = _super.call(this, props);
    _this.state = {
      value: props.value,
      prePropsValue: props.value,
      validateState: '',
      validateMessage: ''
    };
    // 不需要驱动视图更新的数据放这里
    _this._state = {
      initialValue: '',
      isMounted: false
    };
    _this.selectWrapRef = /*#__PURE__*/React.createRef();
    return _this;
  }
  _createClass(Select3, [{
    key: "render",
    value: function render() {
      var _this2 = this;
      return /*#__PURE__*/React.createElement(Consumer, null, function (context) {
        _this2.form = context;
        console.log('Select3 mounted or updated');
        var _this2$props = _this2.props,
          title = _this2$props.title,
          prepend = _this2$props.prepend,
          append = _this2$props.append,
          data = _this2$props.data;
        var validateMessage = _this2.state.validateMessage;
        return /*#__PURE__*/React.createElement("div", {
          className: _this2.wrapCls,
          ref: _this2.selectWrapRef
        }, /*#__PURE__*/React.createElement("div", {
          className: _this2.innerCls
        }, /*#__PURE__*/React.createElement("label", {
          className: _this2.labelCls,
          style: _this2.labelStyle
        }, title), prepend && /*#__PURE__*/React.createElement("div", {
          className: _this2.prependCls
        }, prepend), /*#__PURE__*/React.createElement("div", {
          className: _this2.contentCls
        }, data.map(function (item) {
          return /*#__PURE__*/React.createElement("div", {
            key: item.value,
            className: classNames([_this2.selectOptionCls, {
              active: _this2.state.value === item.value
            }]),
            onClick: function onClick(e) {
              return _this2.onSelect(e, item);
            }
          }, item.text);
        })), append && /*#__PURE__*/React.createElement("div", {
          className: _this2.appendCls
        }, append)), _this2.selectedOption.children && _this2.selectedOption.children.length && /*#__PURE__*/React.createElement("div", {
          className: _this2.wrapChildrenCls
        }, _this2.selectedOption.children.map(function (item, index) {
          return /*#__PURE__*/React.createElement(item.component, _extends({}, item, {
            "data-index": index,
            item: item,
            key: item.name
          }));
        })), _this2.showErrorMsg && /*#__PURE__*/React.createElement("div", {
          className: _this2.errorCls
        }, validateMessage));
      });
    }
  }, {
    key: "componentDidMount",
    value: function componentDidMount() {
      this.form && this.form.addField(this);
      this._state.initialValue = this.state.value;
      this._state.isMounted = true;
      this.$el = this.selectWrapRef.current;
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      this.form && this.form.removeField(this);
      this._state.isMounted = false;
    }
  }, {
    key: "wrapCls",
    get: function get() {
      var value = this.state.value;
      var _this$props = this.props,
        labelPosition = _this$props.labelPosition,
        textPosition = _this$props.textPosition,
        mode = _this$props.mode,
        className = _this$props.className,
        readonly = _this$props.readonly;
      var _labelPosition = labelPosition || this.form && this.form.labelPosition || 'left';
      var _textPosition = textPosition || this.form && this.form.textPosition || 'left';
      var _mode = mode || this.form && this.form.mode || 'default';
      return classNames([this.form && 'form-item', prefixCls, "".concat(prefixCls, "-label-").concat(_labelPosition), "".concat(prefixCls, "-text-").concat(_textPosition), "".concat(prefixCls, "-mode-").concat(_mode), className, _defineProperty(_defineProperty(_defineProperty(_defineProperty({}, "".concat(prefixCls, "-empty"), value === ''), "".concat(prefixCls, "-error"), this.showErrorMsg), "".concat(prefixCls, "-required"), this.isRequired), "".concat(prefixCls, "-readonly"), !!readonly)]);
    }
  }, {
    key: "innerCls",
    get: function get() {
      return "".concat(prefixCls, "-inner");
    }
  }, {
    key: "wrapChildrenCls",
    get: function get() {
      return "".concat(prefixCls, "-children");
    }
  }, {
    key: "labelCls",
    get: function get() {
      return "".concat(prefixCls, "-label");
    }
  }, {
    key: "labelStyle",
    get: function get() {
      var style = {};
      if (this.labelWidth || this.labelWidth === 0) {
        style.width = this.labelWidth;
      } else if (this.form && (this.form.labelWidth || this.form.labelWidth === 0)) {
        style.width = this.form.labelWidth;
      }
      return style;
    }
  }, {
    key: "prependCls",
    get: function get() {
      return "".concat(prefixCls, "-prepend");
    }
  }, {
    key: "appendCls",
    get: function get() {
      return "".concat(prefixCls, "-append");
    }
  }, {
    key: "selectedOption",
    get: function get() {
      var data = this.props.data;
      var value = this.state.value;
      var selectedOption = {};
      for (var i = 0; i < data.length; i++) {
        if (data[i].value === value) {
          selectedOption = data[i];
          break;
        }
      }
      return selectedOption;
    }
  }, {
    key: "contentCls",
    get: function get() {
      return "".concat(prefixCls, "-content");
    }
  }, {
    key: "selectCls",
    get: function get() {
      return "".concat(prefixCls, "-select");
    }
  }, {
    key: "selectOptionCls",
    get: function get() {
      return "".concat(prefixCls, "-select-option");
    }
  }, {
    key: "errorCls",
    get: function get() {
      return "".concat(prefixCls, "-error-tip");
    }
  }, {
    key: "fieldRules",
    get: function get() {
      var _this$props2 = this.props,
        title = _this$props2.title,
        rules = _this$props2.rules;
      var defaultRules = [{
        required: true,
        message: "".concat(title, "\u4E0D\u80FD\u4E3A\u7A7A")
      }];
      return [].concat(rules ? rules : defaultRules);
    }
  }, {
    key: "isRequired",
    get: function get() {
      return this.props.required && this.fieldRules.length > 0;
    }
  }, {
    key: "showErrorMsg",
    get: function get() {
      return this.state.validateState === 'error' && (this.form ? this.form.showMessage && this.props.showMessage : this.props.showMessage);
    }
  }, {
    key: "onSelect",
    value: function onSelect(e, item) {
      var _this$props3 = this.props,
        readonly = _this$props3.readonly,
        disabled = _this$props3.disabled;
      if (readonly || disabled) return;
      this.setValue(item.value, function () {}, {
        event: e,
        from: 'select'
      });
    }
  }, {
    key: "getFilterRules",
    value: function getFilterRules(trigger) {
      return this.fieldRules.filter(function (rule) {
        return !rule.trigger || rule.trigger.indexOf(trigger) !== -1;
      });
    }
  }, {
    key: "validate",
    value: function validate(trigger) {
      var _this3 = this;
      var callback = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : function () {};
      var value = this.state.value;
      var initialValue = this._state.initialValue;
      var _this$props4 = this.props,
        name = _this$props4.name,
        title = _this$props4.title;
      var rules = this.getFilterRules(trigger);
      var isInitialValue = this.isRequired && value !== '' && initialValue === value;
      if (!this.isRequired || isInitialValue) {
        callback();
        return true;
      }
      var prop = name || title || 'prop';
      var descriptor = {};
      descriptor[prop] = rules;
      var validator = new AsyncValidator(descriptor);
      var model = {};
      model[prop] = value;
      validator.validate(model, {
        first: true,
        suppressWarning: true,
        component: this
      }).then(function () {
        _this3.setState({
          validateState: 'success',
          validateMessage: ''
        });
        callback('');
      }).catch(function (_ref2) {
        var errors = _ref2.errors,
          fields = _ref2.fields;
        var errMsg = errors[0].message || '';
        _this3.setState({
          validateState: 'error',
          validateMessage: errMsg
        });
        callback(errMsg);
      });
    }
  }, {
    key: "resetField",
    value: function resetField() {
      this.setState({
        validateState: '',
        validateMessage: ''
      });
      this.setValue(this._state.initialValue, null, {
        from: 'reset'
      });
    }
    /* 获取表单数据 */
  }, {
    key: "getValue",
    value: function getValue() {
      return {
        name: this.props.name,
        value: this.state.value,
        title: this.props.title
      };
    }
  }, {
    key: "setValue",
    value: function setValue(value, callback) {
      var _this4 = this;
      var options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
      var opts = Object.assign({
        event: null,
        component: this,
        value: value
      }, options);
      var from = options.from;
      this._state.isMounted && this.setState({
        value: value
      }, function () {
        _this4.props.onChange(opts);
        _this4.form && _this4.form.onChange(opts);
        callback && callback.call(_this4);
        if (from === 'select') {
          _this4.validate('blur');
        }
      });
    }
  }], [{
    key: "getDerivedStateFromProps",
    value: function getDerivedStateFromProps(nextProps, prevState) {
      if (nextProps.value !== prevState.prePropsValue) {
        return {
          value: nextProps.value,
          prePropsValue: nextProps.value
        };
      }
      return null;
    }
  }]);
  return Select3;
}(React.PureComponent);
setDefaultProps(Select3, {
  title: {
    type: PropTypes.string
  },
  value: {
    type: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
    default: ''
  },
  disabled: {
    type: PropTypes.oneOf(['disabled', 1, 0, true, false])
  },
  readonly: {
    type: PropTypes.oneOf(['readonly', 1, 0, true, false])
  },
  labelPosition: {
    type: PropTypes.oneOf(['left', 'right', 'top'])
  },
  labelWidth: {
    type: PropTypes.string
  },
  textPosition: {
    type: PropTypes.oneOf(['left', 'center', 'right'])
  },
  data: {
    type: PropTypes.array,
    default: []
  },
  // 是否显示校验错误信息
  showMessage: {
    type: PropTypes.bool,
    default: true
  },
  // 校验规则
  rules: {
    type: PropTypes.array
  },
  required: {
    type: PropTypes.bool,
    default: true
  },
  onChange: {
    type: PropTypes.func,
    default: function _default() {}
  },
  mode: {
    type: PropTypes.string
  }
});
export default Select3;
